<template>
  <gree-view>
    <gree-page class="page-diy">
      <gree-header :left-options="{ showBack: false }" :right-options="{ showMore: false }">
        <span v-text="'DIY'" />
        <i class="iconfont iconfont-fanhui" slot="overwrite-left" @click="goBack" />
        <span class="save" v-text="'保存'" slot="right" @click="sceneDIY" />
      </gree-header>
      <div class="page-main">
        <gree-list class="diy-name">
          <gree-list-item title="名称" link text="奶奶爱用的"></gree-list-item>
        </gree-list>
        <div class="diy-mod">
          <span class="diy-mod-title" v-text="'模式'" />
          <gree-scroll-view ref="scrollView2" :scrolling-y="false" :touch-angle="80" :is-prevent="false">
            <div class="scroll-view-list">
              <gree-row>
                <gree-col
                  v-for="(btn, index) in btnList"
                  class="mod-col"
                  :id="`mod-group-${btn.key}`"
                  :class="{
                    'set-gray': btn.gray,
                    'set-hide': btn.hide,
                    select: btn.icon.type === 'on' && !btn.gray,
                    blur: btn.icon.type === 'off' && !btn.gray
                  }"
                  :key="index"
                >
                  <!-- 图标 -->
                  <div class="icon" @click="btn.handler(btn.key, btn.gray)">
                    <i class="iconfont" :class="{ [`iconfont-${btn.icon.key}`]: true }" />
                  </div>
                  <!-- 名称 -->
                  <div class="mod-group-text" v-text="btn.name" />
                </gree-col>
              </gree-row>
            </div>
          </gree-scroll-view>
        </div>
        <gree-divider />
        <div class="diy-temp">
          <span class="diy-temp-title" v-text="'温度'" />
          <vue-slider ref="slider" v-model="value3" v-bind="options3" @change="onChange">
            <template v-slot:process="{ start, end, style }">
              <div
                class="vue-slider-process custom-slider-process"
                :style="[style, { width: `calc(${end - start}% + ${pxTransform(108)})`, left: `${pxTransform(10)}` }]"
              />
            </template>
          </vue-slider>
        </div>
        <div class="diy-windset">
          <gree-list>
            <!-- 风速设置 -->
            <wind-speed />
            <!-- 风向设置 -->
            <wind-direction />
          </gree-list>
        </div>
      </div>
    </gree-page>
  </gree-view>
</template>
<script>
import { Header, List, Item, ScrollView, Row, Col, Divider } from 'gree-ui';
import BtnGroup from '@/components/BtnGroup/index';
import { mapState, mapMutations, mapGetters } from 'vuex';
import WindSpeed from '@/components/WindSet/windSpeed';
import windDirection from '@/components/WindSet/windDirection';
import VueSlider from 'vue-slider-component';
import 'vue-slider-component/theme/default.css';

// import { editDevice } from '@PluginInterface';
export default {
  components: {
    [Header.name]: Header,
    [List.name]: List,
    [Item.name]: Item,
    [Row.name]: Row,
    [Col.name]: Col,
    [Divider.name]: Divider,
    [WindSpeed.name]: WindSpeed,
    [windDirection.name]: windDirection,
    [BtnGroup.name]: BtnGroup,
    [ScrollView.name]: ScrollView,
    VueSlider
  },
  // data() {
  //   return {};
  // },
  data() {
    return {
      value3: 18,
      options3: {
        min: 16,
        max: 30,
        duration: 0.3,
        marks: {
          16: {
            label: '16°'
          },
          30: {
            label: '30°'
          }
        },
        dotOptions: {
          tooltip: 'focus'
        },
        dotStyle: {
          'box-shadow': 'none'
        },
        railStyle: {
          'background-color': '#E7EBEB'
        },
        processStyle: {
          background: 'linear-gradient(to right, #8CBEFC , #6CA1E2)'
        },
        tooltipStyle: {
          padding: 0,
          color: '#404657',
          'border-color': '#fff',
          'background-color': '#fff'
        },
        stepStyle: {
          'background-color': 'transparent'
        },
        stepActiveStyle: {
          'background-color': 'transparent'
        }
      }
    };
  },
  computed: {
    ...mapState('control', {
      dataObject: state => state.dataObject,
      functype: state => state.functype,
      mac: state => state.mac
    }),
    ...mapState('machine', {
      statueJson2: state => state.devOptions.statueJson2
    }),
    ...mapGetters(['modModels']),
    ...mapGetters('machine', ['statusLoop', 'statusMap']),
    btnList() {
      const result = [];
      this.modModels.forEach(model => {
        const statusNameList = this.getLoop(model);
        statusNameList.forEach(statusName => {
          const { identifier } = model;
          const currentStatusName = this.getCurrentStatusName(identifier);
          const stateName = `${identifier}_${statusName}`;
          // status定义
          const status = model.statusDefine[statusName];
          // 名称
          const statusNameText = status.name;
          const stateNameText = this.$language(`mod.${identifier}_${statusNameText}`);
          // 图标
          const icon = {
            key: status.icon.key,
            type: currentStatusName === statusName ? 'on' : 'off'
          };
          // 是否置灰
          const gray = false;
          // 是否隐藏
          const hide = status.icon.key === 'disable';
          // 跳转页面
          const page = false;
          // 执行的函数
          const handler = (_, disable = false) => {
            disable || this.$stateMachine.toStatus(identifier, statusName);
          };
          result.push({ key: stateName, name: stateNameText, icon, gray, hide, page, handler });
        });
      });
      return result;
    }
  },
  watch: {},
  created() {},
  mounted() {
    this.setStatus({ isDIY: true });
  },
  methods: {
    ...mapMutations('control', {
      setDataObject: 'SET_DATA_OBJECT',
      setStatus: 'SET_STATUS'
    }),
    /**
     * @description 返回键
     */
    goBack() {
      this.$router.push('Home');
      this.setStatus({ isDIY: false });
    },
    sceneDIY() {
      let { opt } = this;
      if (!opt || !opt.length) {
        const removeJson = (inputArr, removeJsonList) => {
          removeJsonList.forEach(json => {
            const index = inputArr.indexOf(json);
            if (index !== -1) {
              inputArr.splice(index, 1);
            }
          });
        };
        // 需要去除的字段
        const removeJsonList = ['AppTimer', 'SetDeciTem', 'CleanTime', 'CleanState', 'GetEr', 'MasSub', 'AutoSetTemEn', 'ErrType', 'functype'];
        // 需要添加的字段
        const addJsonList = [];

        opt = JSON.parse(this.statueJson2);
        opt.push(...addJsonList);
        removeJson(opt, removeJsonList);
      }
      const remarks = '...';
      const p = opt.map(item => {
        return this.dataObject[item] === undefined ? 0 : this.dataObject[item];
      });
      const dat = JSON.stringify(p);
      const json = JSON.stringify({ opt, p, t: 'cmd', sub: this.mac });
      console.log('保存diy', { json, remarks, dat });
      // this.$router.push('Home');
      // this.setStatus({ isDIY: false });
    },
    getLoop(model) {
      if (!model) return [];
      const { identifier } = model;
      let result = JSON.parse(JSON.stringify(this.statusLoop[identifier]));
      const startStatusName = 'default';
      const defaultIndex = result.findIndex(statusName => statusName === startStatusName);
      result.unshift(...result.splice(defaultIndex));
      return result;
    },
    getCurrentStatusName(identifier) {
      return String(this.statusMap[identifier].statusName);
    },
    pxTransform(val) {
      return ((window['lib'].flexible.rem / 108) * val).toFixed(5) + 'px';
    },
    onChange(val) {
      console.log(`onChange: ${val}`);
    }
  }
};
</script>

<style lang="scss">
.page-diy {
  .page-content {
    overflow-y: hidden;
  }
  .gree-header {
    background-color: #fff;
    .save {
      padding-right: 20px;
    }
  }
  .page-main {
    background-color: #fff;
    .diy-name {
      .item-content {
        .item-inner {
          .item-after {
            color: #989898;
          }
        }
      }
    }
    .diy-mod {
      position: relative;
      height: 380px;
      &-title {
        // position: absolute;
        display: block;
        padding-top: 44px;
        padding-left: 54px;
        font-size: 40px;
      }
      .gree-scroll-view {
        position: relative;
        height: 280px;
        .scroll-view-container {
          position: absolute;
          bottom: 20px;
          .scroll-view-list {
            .row {
              width: 1200px;
              height: auto;
              display: flex;
              text-align: center;
              justify-content: flex-start;
              align-items: center;
              flex-wrap: wrap;
              .mod-col {
                width: 20%;
                height: 258px;
                display: flex;
                justify-content: center;
                align-content: flex-start;
                flex-wrap: wrap;
                .icon {
                  display: flex;
                  justify-content: center;
                  align-items: center;
                  margin: auto;
                  height: 140px;
                  width: 140px;
                  margin-top: 40px;
                  border-radius: 50%;
                  background-color: rgba(152, 152, 152, 0.15);
                  // background-color: #dbeafa;
                  i {
                    font-size: 72px;
                  }
                }
                .mod-group-text {
                  font-size: 36px;
                  padding-top: 8px;
                  width: 100%;
                }
                #btn-group-Mod_status_1,
                [id^='btn-group-SpMod'] {
                  .icon {
                    background: linear-gradient(rgba(240, 182, 115, 0.2), rgba(250, 210, 157, 0.2)) !important;
                    .iconfont {
                      color: rgba(247, 164, 54, 0.6) !important;
                    }
                  }
                  &.select {
                    .icon {
                      background: linear-gradient(180deg, #fcc0a2 0%, #ff9f70 100%) !important;
                      box-shadow: 0px 8px 22px 0px rgba(246, 137, 8, 0.15) !important;
                      .iconfont {
                        color: #fff !important;
                      }
                    }
                  }
                }
                &.select {
                  .icon {
                    background-image: linear-gradient(rgb(141, 191, 253), rgb(119, 167, 224));
                    box-shadow: 0 9px 21px rgba(14, 110, 227, 0.15);
                    i {
                      color: #fff;
                    }
                  }
                }
                &.blur {
                  .icon {
                    transition: all 0.5s;
                    box-shadow: 0 3px 24px rgba(64, 70, 87, 0.03);
                  }
                }
              }
            }
          }
        }
      }
    }
    .gree-divider {
      margin: 0px;
    }
    .diy-temp {
      position: relative;
      // .list {
      height: 360px;
      &-title {
        display: block;
        padding-top: 44px;
        padding-bottom: 50px;
        padding-left: 54px;
        font-size: 40px;
      }
      .vue-slider {
        width: 880px !important;
        height: 92px !important;
        .vue-slider-rail {
          transform: translateX(100px);
          &::before,
          &::after {
            content: '';
            position: absolute;
            top: 50%;
            transform: translateY(-50%);
            width: 66px;
            height: 92px;
          }
          &::before {
            left: -58px;
            background: #e7ebeb;
            border-top-left-radius: 92px;
            border-bottom-left-radius: 92px;
          }
          &::after {
            right: -56px;
            top: 46px;
            background: #e7ebeb;
            border-top-right-radius: 92px;
            border-bottom-right-radius: 92px;
          }
          .vue-slider-process {
            transform: translateX(-65px);
            border-radius: 92px;
          }
          .vue-slider-marks {
            transform: translateX(10px);
            padding-top: 20px;
            .vue-slider-mark {
              width: 66px !important;
              height: 66px !important;
              &:first-child .vue-slider-mark-step,
              &:last-child .vue-slider-mark-step {
                display: inherit;
              }
              .vue-slider-mark-label {
                font-size: 36px;
              }
            }
          }
        }

        .vue-slider-dot {
          width: 66px !important;
          height: 66px !important;
        }

        .vue-slider-dot-tooltip-top {
          top: -34px;
          box-shadow: 6px 6px 10px rgba(0, 0, 0, 0.1);
          border-radius: 86px;
          .vue-slider-dot-tooltip-inner {
            width: 174px;
            height: 60px;
            font-size: 42px;
            border-radius: inherit;
            &::after {
              border-width: 14px;
            }
          }
        }
      }
      // }
    }
    .diy-windset {
      .list {
        .wind-box-header {
          .wind-box-header-icon {
            display: none;
          }
        }
        .wind-speed-set.wind-box {
          padding-top: 44px;
          .wind-speed-set-content {
            transform: translateY(-30px);
            width: 984px;
            .wind-speed-set-content-slider-content-bar {
              width: 984px;
            }
          }
        }
      }
    }
  }
}
</style>
